%global erlang_minver R12B-3
# We want to install into /usr/lib, even on 64-bit platforms
%global _rabbit_libdir %{_exec_prefix}/lib/rabbitmq


Name: rabbitmq-server
Version: 3.6.9
Release: %mkrel 1
License: MPLv1.1
Group: Development/Other
Source0: http://www.rabbitmq.com/releases/rabbitmq-server/v%{version}/%{name}-%{version}.tar.xz
# curl -O https://raw.githubusercontent.com/rabbitmq/rabbitmq-server/231e90c/scripts/rabbitmq-script-wrapper
# sed -i -e "s, @STDOUT_STDERR_REDIRECTION@,,g" rabbitmq-script-wrapper
# sed -i -e "s,@SU_RABBITMQ_SH_C@,su rabbitmq -s /bin/sh -c,g" rabbitmq-script-wrapper
Source2: rabbitmq-script-wrapper
# curl -O https://raw.githubusercontent.com/lemenkov/rabbitmq-server/cdfc661/packaging/RPMS/Fedora/rabbitmq-server.logrotate
Source3: rabbitmq-server.logrotate
Source5: rabbitmq-server.tmpfiles
Patch1: rabbitmq-server-0001-Remove-excessive-sd_notify-code.patch
Patch2: rabbitmq-server-0002-Add-systemd-notification-support.patch
Patch3: rabbitmq-server-0003-Revert-Distinct-exit-codes-for-CLI-utilities.patch
Patch4: rabbitmq-server-0004-Allow-guest-login-from-non-loopback-connections.patch
Patch5: rabbitmq-server-0005-rabbit_prelaunch-must-use-RABBITMQ_SERVER_ERL_ARGS.patch
Patch101: rabbitmq-common-0001-Use-proto_dist-from-command-line.patch

URL: http://www.rabbitmq.com/
BuildArch: noarch
BuildRequires: erlang >= %{erlang_minver}, python-simplejson, xmlto, libxslt-proc, python, zip
BuildRequires: rsync
BuildRequires: systemd
Requires: logrotate
Requires: erlang-erts >= %{erlang_minver}
Requires: erlang-kernel >= %{erlang_minver}
Requires: erlang-eldap >= %{erlang_minver}
Requires: erlang-mnesia >= %{erlang_minver}
Requires: erlang-os_mon >= %{erlang_minver}
Requires: erlang-public_key >= %{erlang_minver}
Requires: erlang-sasl >= %{erlang_minver}
Requires: erlang-sd_notify
Requires: erlang-ssl >= %{erlang_minver}
Requires: erlang-stdlib >= %{erlang_minver}
Requires: erlang-tools >= %{erlang_minver}
Requires: erlang-xmerl >= %{erlang_minver}
Summary: The RabbitMQ server
# Users and groups
Requires(pre): shadow-utils
Requires(pre): systemd
Requires(post): systemd
Requires(preun): systemd

%description
RabbitMQ is an implementation of AMQP, the emerging standard for high
performance enterprise messaging. The RabbitMQ server is a robust and
scalable implementation of an AMQP broker.

%prep
%setup -q

cd deps/rabbit
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
cd ../..

cd deps/rabbit_common
%patch101 -p1
cd ../..

# We have to remove it until common_test subpackage lands RHOS
rm -f \
	deps/amqp_client/src/rabbit_ct_client_helpers.erl \
	deps/rabbit_common/src/rabbit_ct_broker_helpers.erl \
	deps/rabbit_common/src/rabbit_ct_helpers.erl

%build
#USE_SPECS="true" USE_PROPER_QC="false" make %{?_smp_mflags}
%make VERSION="%{version}"


%install
%makeinstall \
	VERSION="%{version}" \
	DESTDIR=%{buildroot} \
	PREFIX=%{_prefix} \
	RMQ_ROOTDIR=%{_rabbit_libdir}

make install-man \
	VERSION="%{version}" \
	DESTDIR=%{buildroot} \
	PREFIX=%{_prefix} \
	RMQ_ROOTDIR=%{_rabbit_libdir}

mkdir -p %{buildroot}%{_localstatedir}/lib/rabbitmq/mnesia
mkdir -p %{buildroot}%{_localstatedir}/log/rabbitmq

#Copy all necessary lib files etc.
install -p -D -m 0644 ./deps/rabbit/docs/rabbitmq-server.service.example %{buildroot}%{_unitdir}/%{name}.service
install -p -D -m 0755 %{S:2} %{buildroot}%{_sbindir}/rabbitmqctl
install -p -D -m 0755 %{S:2} %{buildroot}%{_sbindir}/rabbitmq-server
install -p -D -m 0755 %{S:2} %{buildroot}%{_sbindir}/rabbitmq-plugins

# Make necessary symlinks
mkdir -p %{buildroot}%{_rabbit_libdir}/bin
for app in rabbitmq-defaults rabbitmq-env rabbitmq-plugins rabbitmq-server rabbitmqctl ; do
	ln -s %{_rabbit_libdir}/lib/rabbitmq_server-%{version}/sbin/${app} %{buildroot}%{_rabbit_libdir}/bin/${app}
done

install -p -D -m 0755 scripts/rabbitmq-server.ocf %{buildroot}%{_exec_prefix}/lib/ocf/resource.d/rabbitmq/rabbitmq-server
install -p -D -m 0755 scripts/rabbitmq-server-ha.ocf %{buildroot}%{_exec_prefix}/lib/ocf/resource.d/rabbitmq/rabbitmq-server-ha

install -p -D -m 0644 %{S:3} %{buildroot}%{_sysconfdir}/logrotate.d/rabbitmq-server

install -p -D -m 0644 ./deps/rabbit/docs/rabbitmq.config.example %{buildroot}%{_sysconfdir}/rabbitmq/rabbitmq.config

install -d %{buildroot}%{_localstatedir}/run/rabbitmq
install -p -D -m 0644 %{SOURCE5} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf


%check
#make check


%pre
# create rabbitmq group
if ! getent group rabbitmq >/dev/null; then
        groupadd -r rabbitmq
fi

# create rabbitmq user
if ! getent passwd rabbitmq >/dev/null; then
        useradd -r -g rabbitmq -d %{_localstatedir}/lib/rabbitmq rabbitmq \
            -s /sbin/nologin -c "RabbitMQ messaging server"
fi


%post
%_post_service %{name}
%_tmpfilescreate %{name}

%preun
# We do not remove /var/log and /var/lib directories
# Leave rabbitmq user and group
%_preun_service %{name}

# Clean out plugin activation state, both on uninstall and upgrade
rm -rf %{_localstatedir}/lib/rabbitmq/plugins
for ext in rel script boot ; do
    rm -f %{_rabbit_libdir}/lib/rabbitmq_server-%{version}/ebin/rabbit.$ext
done


%postun
%_postun_service %{name}

# Fix root:root ownership for config-files (recursively)
%triggerun -- %{name} < 3.5.7-3
/usr/bin/chown -R rabbitmq:rabbitmq %{_sysconfdir}/rabbitmq

%files
%dir %attr(0755, rabbitmq, rabbitmq) %{_sysconfdir}/rabbitmq
%config(noreplace) %attr(0644, rabbitmq, rabbitmq) %{_sysconfdir}/rabbitmq/rabbitmq.config
%config(noreplace) %{_sysconfdir}/logrotate.d/rabbitmq-server
%{_sbindir}/rabbitmqctl
%{_sbindir}/rabbitmq-server
%{_sbindir}/rabbitmq-plugins
%{_rabbit_libdir}/
%{_unitdir}/%{name}.service
# FIXME this should add dependency on "/usr/lib/ocf/resource.d/" owner
%dir %_prefix/lib/ocf/resource.d/rabbitmq/
%_prefix/lib/ocf/resource.d/rabbitmq/rabbitmq-server
%_prefix/lib/ocf/resource.d/rabbitmq/rabbitmq-server-ha
%{_tmpfilesdir}/%{name}.conf
%dir %attr(0750, rabbitmq, rabbitmq) %{_localstatedir}/lib/rabbitmq
%dir %attr(0750, rabbitmq, rabbitmq) %{_localstatedir}/log/rabbitmq
%doc LICENSE LICENSE-*
%{_mandir}/man1/rabbitmq-plugins.1*
%{_mandir}/man1/rabbitmq-server.1*
%{_mandir}/man1/rabbitmqctl.1*
%{_mandir}/man5/rabbitmq-env.conf.5*




%changelog
* Tue May 16 2017 neoclust <neoclust> 3.6.9-1.mga6
+ Revision: 1102008
- New version 3.6.9

* Mon May 30 2016 pterjan <pterjan> 3.6.2-4.mga6
+ Revision: 1019366
- Do not have dependencies depending on build arch in a noarch package

* Sun May 29 2016 neoclust <neoclust> 3.6.2-3.mga6
+ Revision: 1019268
- imported package rabbitmq-server


* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Nov 08 2011 Peter Lemenkov <lemenkov@gmail.com> - 2.6.1-1
- New Upstream Release - 2.6.1
- Fixed rhbz #738067 (service cannot start - rabbitmq-multi missing)

* Mon Sep 12 2011 Peter Lemenkov <lemenkov@gmail.com> - 2.6.0-1
- New Upstream Release - 2.6.0

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jan 15 2011 Hubert Plociniczak <hubert.plociniczak@gmail.com> 2.2.0-1
- New Upstream Release

* Mon Nov 1 2010 Hubert Plociniczak <hubert.plociniczak@gmail.com> 2.1.1-1
- New Upstream Release

* Tue Oct 5 2010 Hubert Plociniczak <hubert.plociniczak@gmail.com> 2.1.0-1
- New Upstream Release
- Added python as a build dependency

* Mon Aug 23 2010 Mike Bridgen <mikeb@rabbitmq.com> 2.0.0-1
- New Upstream Release

* Mon Jun 28 2010 Hubert Plociniczak <hubert@lshift.net> 1.8.0-1
- New Upstream Release
- Backported fix for bug 22871, fixes issues with erlang >= R14A

* Mon Feb 15 2010 Matthew Sackman <matthew@lshift.net> 1.7.2-1
- New Upstream Release

* Fri Jan 22 2010 Matthew Sackman <matthew@lshift.net> 1.7.1-1
- New Upstream Release

* Mon Oct 5 2009 David Wragg <dpw@lshift.net> 1.7.0-1
- New upstream release

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jun 17 2009 Matthias Radestock <matthias@lshift.net> 1.6.0-1
- New upstream release

* Tue May 26 2009 Hubert Plociniczak <hubert@lshift.net> 1.5.5-2
- Include dist macro in the release number

* Tue May 19 2009 Matthias Radestock <matthias@lshift.net> 1.5.5-1
- Maintenance release for the 1.5.x series

* Mon Apr 6 2009 Matthias Radestock <matthias@lshift.net> 1.5.4-1
- Maintenance release for the 1.5.x series

* Tue Feb 24 2009 Tony Garnock-Jones <tonyg@lshift.net> 1.5.3-1
- Maintenance release for the 1.5.x series

* Mon Feb 23 2009 Tony Garnock-Jones <tonyg@lshift.net> 1.5.2-1
- Maintenance release for the 1.5.x series

* Mon Jan 19 2009 Ben Hood <0x6e6562@gmail.com> 1.5.1-1
- Maintenance release for the 1.5.x series

* Wed Dec 17 2008 Matthias Radestock <matthias@lshift.net> 1.5.0-1
- New upstream release

* Thu Jul 24 2008 Tony Garnock-Jones <tonyg@lshift.net> 1.4.0-1
- New upstream release

* Mon Mar 3 2008 Adrien Pierard <adrian@lshift.net> 1.3.0-1
- New upstream release

* Wed Sep 26 2007 Simon MacMullen <simon@lshift.net> 1.2.0-1
- New upstream release

* Wed Aug 29 2007 Simon MacMullen <simon@lshift.net> 1.1.1-1
- New upstream release

* Mon Jul 30 2007 Simon MacMullen <simon@lshift.net> 1.1.0-1.alpha
- New upstream release

* Tue Jun 12 2007 Hubert Plociniczak <hubert@lshift.net> 1.0.0-1.20070607
- Building from source tarball, added starting script, stopping

* Mon May 21 2007 Hubert Plociniczak <hubert@lshift.net> 1.0.0-1.alpha
- Initial build of server library of RabbitMQ package
